@@ -20,7 +20,7 @@
 	############################################################	*/
 #ifndef ID_CHARS_C
 #define	ID_CHARS_C
-const char *id_chr_c= "@(#) chr.c       22.04.1999";
+const char *id_chr_c= "@(#) chr.c       05.02.2004";
 #endif
 
 #include "import.h"
@@ -36,6 +36,8 @@ const char *id_chr_c= "@(#) chr.c       22.04.1999";
 #include "msg.h"
 #include "str.h"
 #include "sty.h"
+/* New: Fixed bug #0000040 in r6.3pl16 [NHz] */
+#include "tp.h"
 #include "udo.h"
 #include "chr_all.h"
 #include "chr_ttf.h"
@@ -330,7 +332,9 @@ LOCAL void iso2system ( char *s )
 LOCAL void iso2sys ( char *s )
 {
 	if (iCharset==CODE_LAT1)	/* PL14: TOLYX */
-	{	if ( desttype==TOWIN || desttype==TOWH4 || desttype==TORTF || desttype==TOAQV || desttype==TOLYX )
+	{	/* Changed: Fixed Bug #0000040 in r6.3pl16 [NHz] */
+		/* Supplement of desttype==TOKPS */
+		if ( desttype==TOWIN || desttype==TOWH4 || desttype==TORTF || desttype==TOAQV || desttype==TOLYX || desttype==TOKPS )
 		{	return;
 		}
 	}
@@ -1380,8 +1384,40 @@ GLOBAL void node2postscript ( char *s, int text )
 {
 	switch(text)
 	{
+		/* New: Fixed bug #0000040 in r6.3pl16 [NHz] */
+		case KPS_PS2DOCINFO:
+			qreplace_all(s, "\\[", 2, "[", 1);
+			qreplace_all(s, "\\]", 2, "]", 1);
+			break;
+
+		case KPS_DOCINFO2PS:
+			qreplace_all(s, "[", 1, "\\[", 2);
+			qreplace_all(s, "]", 1, "\\]", 2);
+			break;
+
+		case KPS_NODENAME:
+			if(strlen(s) > 80L-strlen(titdat.author))
+			{
+				s[80L-strlen(titdat.author)] = EOS;
+				if(s[79L-strlen(titdat.author)] == '\\')
+					s[79L-strlen(titdat.author)] = EOS;
+				strcat(s, "...\0");
+			}
+			/* Changed in V6.4.1 [NHz] */
+			qreplace_all(s, "(", 1, "\\(", 2);
+			qreplace_all(s, ")", 1, "\\)", 2);
+			/* Changed: Fixed bug #0000062 in V6.4.1 [NHz] */
+			qreplace_all(s, "[", 1, "\\[", 2);
+			qreplace_all(s, "]", 1, "\\]", 2);
+			break;
+		
 		case KPS_CONTENT:
 			qreplace_all(s, "/", 1, "\\/", 2);
+			/* Changed in V6.4.1 [NHz] */
+			qreplace_all(s, "(", 1, "\\(", 2);
+			qreplace_all(s, ")", 1, "\\)", 2);
+			qreplace_all(s, "[", 1, "\\[", 2);
+			qreplace_all(s, "]", 1, "\\]", 2);
 			break;
 
 		case KPS_BOOKMARK:
@@ -1392,6 +1428,11 @@ GLOBAL void node2postscript ( char *s, int text )
 					s[31] = EOS;
 			}
 			qreplace_all(s, "/", 1, "\\/", 2);
+			/* Changed in V6.4.1 [NHz] */
+			qreplace_all(s, "(", 1, "\\(", 2);
+			qreplace_all(s, ")", 1, "\\)", 2);
+			qreplace_all(s, "[", 1, "\\[", 2);
+			qreplace_all(s, "]", 1, "\\]", 2);
 			break;
 		
 		case KPS_NAMEDEST:
@@ -1399,8 +1440,14 @@ GLOBAL void node2postscript ( char *s, int text )
 			qdelete_all(s, ";", 1);
 			qdelete_all(s, ":", 1);
 			qdelete_all(s, "/", 1);
+			/* New: Fixed Bug #0000040 in r6.3pl16 [NHz] */
+			qdelete_all(s, "\\[", 2);
+			qdelete_all(s, "[", 1);
 			qdelete_all(s, "\\(", 2);
 			qdelete_all(s, "(", 1);
+			/* New: Fixed Bug #0000040 in r6.3pl16 [NHz] */
+			qdelete_all(s, "\\]", 2);
+			qdelete_all(s, "]", 1);
 			qdelete_all(s, "\\)", 2);
 			qdelete_all(s, ")", 1);
 			qdelete_all(s, "-", 1);
@@ -1759,15 +1806,16 @@ LOCAL void specials2html ( char *s )
 	------------------------------------------------------------	*/
 LOCAL void specials2ps ( char *s )
 {
-	qreplace_all(s, "!..", 3, " ) udoshow ellipsis ( ", 22);
-
-	
 	qreplace_all(s, "(---)", 5, TEMPO_S, TEMPO_S_LEN);
 	qreplace_all(s, "(--)", 4, TEMPO_S2, TEMPO_S2_LEN);
-	qreplace_all(s, "---", 3, "\\075", 4);
-	qreplace_all(s, "--", 2, "\\262", 4);
+	qreplace_all(s, "---", 3, "\\230", 4);
+	qreplace_all(s, "--", 2, "\\227", 4);
 	qreplace_all(s, TEMPO_S, TEMPO_S_LEN, "---", 3);
 	qreplace_all(s, TEMPO_S2, TEMPO_S2_LEN, "--", 2);
+
+	/* Changed in V6.4.1 [NHz] */
+	qreplace_all(s, "!..", 3, "\\214", 4);	/* according to table in ud2ps.h */
+	qreplace_all(s, COPY_S, COPY_S_LEN, "\\251", 4);
 }
 
 /*	------------------------------------------------------------
@@ -2028,13 +2076,20 @@ GLOBAL void c_vars ( char *s )
 			qreplace_all(s, TEMPO_S, TEMPO_S_LEN, "&quot;&quot;", 12);
 			qreplace_all(s, TEMPO_S2, TEMPO_S2_LEN, "''", 2);
 			break;
-		/* New in r6pl16 [NHz] */
+		/* Changed in V6.4.1 [NHz] */
 		case TOKPS:
-			{	switch (destlang)
-				{	case TOGER:	c_quotes_apostrophes(s, ") udoshow /quotesinglbase glyphshow (", ") udoshow /quoteleft glyphshow ( ", ") udoshow /quotedblbase glyphshow (", ") udoshow /quotedblleft glyphshow ( ");	break;
-					case TOFRA:	c_quotes_apostrophes(s, ") udoshow /guilsinglleft glyphshow (", ") udoshow /guilsinglright glyphshow ( ", "\\253", "\\273");	break;
-					case TONOR:	c_quotes_apostrophes(s, "\\<", "\\>", "\\\\\\(", "\\\\\\(");	break;
-					default:	c_quotes_apostrophes(s, ") udoshow /quotesingle glyphshow (", ") udoshow /quotesingle glyphshow (", "\\042", "\\042");	break;
+			{	
+				switch (destlang)
+				{	case TOGER:	/* according to table in ud2ps.h */
+											c_quotes_apostrophes(s, "\\220", "\\221", "\\226", "\\225");
+											break;
+					case TOFRA:	/* according to table in ud2ps.h */
+											c_quotes_apostrophes(s, "\\222", "\\223", "\\253", "\\273");
+											break;
+					case TONOR:	c_quotes_apostrophes(s, "\\<", "\\>", "\\\\\\(", "\\\\\\)");
+											break;
+					default:		c_quotes_apostrophes(s, "'", "'", "\"", "\"");
+											break;
 				}
 			}
 			qreplace_all(s, TEMPO_S, TEMPO_S_LEN, "\"\"", 2);
@@ -2099,8 +2154,9 @@ GLOBAL void c_vars ( char *s )
 /*			qreplace_all(s, "\\(--\\)", 6, "--", 2);*/
 			/* For future use, but commented because of some problems */
 
-			/* specials2ps(s);*/
-			specials2ascii(s);
+			/* Changed in V6.4.1 [NHz] */
+			specials2ps(s);
+			/*specials2ascii(s);*/
 			texvar2ascii(s);
 			break;
 		case TOASC:
@@ -2719,11 +2775,15 @@ GLOBAL void auto_quote_chars ( char *s, BOOLEAN all )
 						ptr_quoted= s_temp;
 					}
 				}
-#if 1
+/* Changed in V6.4.1 [NHz] */
+#if 0
 				else
 				{
 					LOCAL QUOTEINFO const ps7bit[]=
 					{
+						{	'[',		"\\["	},
+						{	']',		"\\]"	},
+
 						{	'(',		"\\("	},
 						{	')',		"\\)"	},
 						{	'\\',		"\\\\"	}
