@@ -35,6 +35,7 @@ const char *id_cli_c= "@(#) cli.c       21.08.1998";
 #include	"cfg.h"
 #include	"msg.h"
 #include	"udo.h"
+#include        "udomem.h"
 
 #ifdef __TOS__
 	#ifdef USE_PCTOS
@@ -74,8 +75,6 @@ LOCAL BOOLEAN	bShowIdent;
 LOCAL int last_percent;
 
 #define	PRGNAME		"udo"
-#define	COPYRIGHT	"Copyright (c) 1995-2001 by Dirk Hagedorn (UDO is Open Source)"
-
 
 /*	############################################################
 	# lokale Prototypen
@@ -445,10 +444,12 @@ GLOBAL BOOLEAN break_action ( void )
 	----------------------------------------------------------------------	*/
 LOCAL void show_version ( void )
 {
-	fprintf(stdout, "\n%s\n", strPrgname);
-	fprintf(stdout, "Release %s.%s Patchlevel %s for %s, %s %s\n",
+	/* fprintf(stdout, "\n%s\n", strPrgname); v6.4.1[vj]: commented out (wished by Ulrich Kretschmer) */
+	fprintf(stdout, "UDO Version %s.%s.%s for %s, %s %s\n",
 				UDO_REL, UDO_SUBVER, UDO_PL, UDO_OS, compile_date, compile_time);
 	fprintf(stdout, "%s\n", COPYRIGHT);
+	sprintf(sInfMsg, "UDO is Open Source (see %s for further information).\n", UDO_URL);
+	fprintf(stdout, sInfMsg);
 }
 
 extern const char *id_abo_c;
@@ -613,7 +614,7 @@ LOCAL BOOLEAN read_cliopt_file ( const char *name )
 		sl= strlen(ptr);
 		if (sl>0)
 		{	if ( counter+1<MAX_FILE_ARGV )
-			{	mp= (char *) malloc ( sl * sizeof(char) + 1 );
+			{	mp= (char *) um_malloc ( sl * sizeof(char) + 1 );
 				if (mp)
 				{	counter++;
 					fargv[counter]= mp;
@@ -633,7 +634,7 @@ LOCAL BOOLEAN read_cliopt_file ( const char *name )
 	
 	for (i=counter; i>=0; i--)
 	{	if (fargv[i]!=NULL)
-		{	free(fargv[i]);
+		{	um_free(fargv[i]);
 			fargv[i]= NULL;
 		}
 	}
@@ -736,6 +737,10 @@ int main ( int argc, const char *argv[] )
 	char	nam[32], *ptr;
 	BOOLEAN cliok;
 
+        /* One of the first things to do: init UDO memory management,
+        else um_malloc can not be called. */
+        init_um();
+
 	/* ---Programmnamen ermitteln--- */
 #ifdef __TOS__
 	Pdomain(1);
@@ -746,14 +751,14 @@ int main ( int argc, const char *argv[] )
 
 	/* globale Variablen initialisieren */
 	init_vars();
-	sprintf(nam, "UDO Release %s", UDO_REL);
+	sprintf(nam, "UDO Version %s", UDO_REL);
 #ifdef __WIN32__
 	init_module_config("udo32.ini", nam, UDO_OS);
 #else
 	init_module_config("udo.ini", nam, UDO_OS);
 #endif
 	read_profile();
-	
+
 	outfile.file= stdout;
 	infile.file= stdin;
 
@@ -782,11 +787,11 @@ int main ( int argc, const char *argv[] )
 	bShowHelp = FALSE;
 	bShowIdent = FALSE;
 	last_percent = -1;
-	
+
 	outfile.full[0]= EOS;
 	infile.full[0]= EOS;
 	sLogfull[0]= EOS;
-	
+
 	no_stderr_output= FALSE;		/* r5pl9 */
 
 	if ( (ptr=getenv("LANG"))!=NULL )
@@ -800,7 +805,7 @@ int main ( int argc, const char *argv[] )
 		{	eLanguage=DEUTSCH;
 		}
 	}
-	
+
 	if ( (ptr=getenv("LC_MESSAGES"))!=NULL )
 	{	if ( strstr(ptr, "german") )
 		{	eLanguage=DEUTSCH;
@@ -848,7 +853,7 @@ int main ( int argc, const char *argv[] )
 		else
 		{
 			fsplit(infile.full, infile.driv, infile.path, infile.name, infile.suff);
-	
+
 			if (outfile.full[0]!=EOS)
 			{	fsplit(outfile.full, outfile.driv, outfile.path, outfile.name, outfile.suff);
 				if ( strcmp(outfile.name, "!")==0 )
@@ -862,18 +867,20 @@ int main ( int argc, const char *argv[] )
 			{	bNoLogfile= TRUE;
 				bNoHypfile= TRUE;
 			}
-	
+
 			if (desttype==TOUDO)
 			{
 				udo2udo(infile.full);
 			}
 			else
-			{	
+			{
 				udo(infile.full);	/* <???> informativeren Exitcode ermitteln */
 			}
 		}
 	}
-		
+
+	exit_um(); /* Call memory management to clean up memory allocated */
+
 	wait_on_keypress();
 	
 	if (!cliok || bErrorDetected || get_error_counter() > 0)
