@@ -1457,7 +1457,7 @@ LOCAL void c_begin_list ( int listkind )
 
 	sShort[0]= EOS;
 	token[0][0]= EOS;
-	tokcpy2(sWidth);
+	tokcpy2(sWidth, 256);
 	delete_once(sWidth, "[");
 	delete_last(sWidth, "]");
 
@@ -1645,7 +1645,7 @@ LOCAL void add_description ( void )
 	
 	if ( sl>1 && token[1][sl-1]==']' && token[1][sl-2]!='!' )
 	{	replace_all(token[1], "!]", "]");
-		strcat(token[0], token[1]);
+		um_strcat(token[0], token[1], MAX_TOKEN_LEN+1, "add_description [1]");
 		token[1][0]= EOS;
 		return;
 	}
@@ -1663,8 +1663,8 @@ LOCAL void add_description ( void )
 		{
 			if ( (found=strchr(token[i], ']'))==NULL )
 			{
-				strcat(token[0], token[i]);	/* <???> Ueberlauf moeglich! */
-				strcat(token[0], " ");
+				um_strcat(token[0], token[i], MAX_TOKEN_LEN+1, "add_description [2]");
+				um_strcat(token[0], " ", MAX_TOKEN_LEN+1, "add_description [3]");
 				token[i][0]= EOS;
 				i++;
 			}
@@ -1679,13 +1679,13 @@ LOCAL void add_description ( void )
 					
 				if (found==NULL)
 				{	/* wie oben */
-					strcat(token[0], token[i]);	/* <???> Ueberlauf moeglich! */
-					strcat(token[0], " ");
+					um_strcat(token[0], token[i], MAX_TOKEN_LEN+1, "add_description [4]");
+					um_strcat(token[0], " " , MAX_TOKEN_LEN+1, "add_description [5]");
 					token[i][0]= EOS;
 					i++;
 				}
 				else
-				{	strcat(token[0], token[i]);
+				{	um_strcat(token[0], token[i], MAX_TOKEN_LEN+1, "add_description [6]");
 					token[i][0]= EOS;
 					finished= TRUE;
 					no_bracket= FALSE;
@@ -1733,7 +1733,7 @@ GLOBAL void c_item ( void )
 	{
 		case TOTEX:
 		case TOPDL:
-			strcpy(token[0], "\\item");
+			um_strcpy(token[0], "\\item", MAX_TOKEN_LEN+1, "c_item [1]");
 			switch(iEnvType[iEnvLevel])
 			{	case ENV_DESC:
 				case ENV_LIST:
@@ -1786,11 +1786,11 @@ GLOBAL void c_item ( void )
 					{
 						case LIST_BOLD:
 							strinsert(token[0], "\\series bold ");
-							strcat(token[0], "\\series default ");
+							um_strcat(token[0], "\\series default ", MAX_TOKEN_LEN+1, "c_item[2]");
 							break;
 						case LIST_ITALIC:
 							strinsert(token[0], "\\shape italic ");
-							strcat(token[0], "\\shape default ");
+							um_strcat(token[0], "\\shape default ", MAX_TOKEN_LEN+1, "c_item[3]");
 							break;
 					}
 					break;
@@ -1798,7 +1798,7 @@ GLOBAL void c_item ( void )
 			break;	/* TOLYX */
 			
 		case TOINF:
-			strcpy(token[0], "@item ");
+			um_strcpy(token[0], "@item ", MAX_TOKEN_LEN+1, "c_item[4]");
 			switch(iEnvType[iEnvLevel])
 			{	case ENV_DESC:
 				case ENV_LIST:
@@ -1807,7 +1807,7 @@ GLOBAL void c_item ( void )
 						delete_once(token[0], "[");
 						delete_last(token[0], "]");
 					}
-					strcat(token[0], "\n");
+					um_strcat(token[0], "\n", MAX_TOKEN_LEN+1, "c_item[5]");
 					break;
 			}
 			break;
@@ -1828,7 +1828,7 @@ GLOBAL void c_item ( void )
 					{
 						memset(sAdd, ' ', (size_t) (tl-1) );
 						sAdd[tl-1]= EOS;
-						strcat(token[0], sAdd);
+						um_strcat(token[0], sAdd, MAX_TOKEN_LEN+1, "c_item[6]");
 						token[0][tl-2]= itemchar[iItemLevel][0];
 					}
 					break;
@@ -1843,7 +1843,7 @@ GLOBAL void c_item ( void )
 					{
 						memset(sAdd, ' ', (size_t) (tl-1) );
 						sAdd[tl-1]= EOS;
-						strcat(token[0], sAdd);
+						um_strcat(token[0], sAdd, MAX_TOKEN_LEN+1, "c_item[7]");
 						for (i=0; i<sl; i++)
 						{	token[0][tl-sl-1+i]= s[i];
 						}
@@ -1863,7 +1863,7 @@ GLOBAL void c_item ( void )
 							delete_once(token[0], "[");
 							delete_last(token[0], "]");
 							del_internal_styles(token[0]);
-							strcpy(sTemp, token[0]);
+							um_strcpy(sTemp, token[0], 1024, "c_item[8]");
 							replace_all(sTemp, "\"", "\\\"");
 							replace_2at_by_1at(sTemp);	/* r6pl1 */
 							sprintf(sBig, "@{B}@{\"%s\" ignore}@{b}", sTemp);
@@ -1883,7 +1883,7 @@ GLOBAL void c_item ( void )
 						}
 					}
 #else		/* Alte Version, ohne !autoref_items-Unterstuetzung */
-					strcpy(token[0], " ");
+					um_strcpy(token[0], " ", MAX_TOKEN_LEN+1, "c_item[9]");
 					strcat_prev_indent(token[0]);
 					if (token[1][0]=='[')
 					{
@@ -1908,7 +1908,7 @@ GLOBAL void c_item ( void )
 
 					/* PL16: Das leidige @@-Problem beim ST-Guide */
 					if (desttype==TOSTG)
-					{	strcpy(sBig, token[0]);
+					{	um_strcpy(sBig, token[0], 1024, "c_item[10]");
 						replace_2at_by_1at(sBig);
 						tl= toklen(sBig);
 					}
@@ -1930,7 +1930,7 @@ GLOBAL void c_item ( void )
 					if (desttype==TOSTG && bDocAutorefItemsOff)
 					{
 						del_internal_styles(token[0]);
-						strcpy(sTemp, token[0]);
+						um_strcpy(sTemp, token[0], 1024, "c_item[11]");
 						replace_all(sTemp, "\"", "\\\"");
 						sprintf(sBig, "@{\"%s\" ignore}", sTemp);
 						switch (env_kind[iEnvLevel])
@@ -1956,7 +1956,7 @@ GLOBAL void c_item ( void )
 						{	token[0][0]= EOS;
 						}
 						
-						strcpy(token[0], sBig);
+						um_strcpy(token[0], sBig, 1024, "c_item[12]");
 					}
 					else
 					{
@@ -1973,8 +1973,8 @@ GLOBAL void c_item ( void )
 			 					break;
 			 			}
 
-						strcpy(token[0], s);
-						strcat(token[0], sAdd);
+						um_strcpy(token[0], s, MAX_TOKEN_LEN+1, "c_item[13]");
+						um_strcat(token[0], sAdd, MAX_TOKEN_LEN+1, "c_item[14]");
 					}
 
 					break;
@@ -1991,7 +1991,7 @@ GLOBAL void c_item ( void )
 			switch (iEnvType[iEnvLevel])
 			{
 				case ENV_ITEM:
-					strcpy(token[0], ".TP\n.B o\n");
+					um_strcpy(token[0], ".TP\n.B o\n", MAX_TOKEN_LEN+1, "c_item[15]");
 					break;
 				case ENV_ENUM:
 					enum_count[iEnvLevel]++;
@@ -1999,7 +1999,7 @@ GLOBAL void c_item ( void )
 					sprintf(token[0], ".TP\n.B %s\n", s);
 					break;
 				case ENV_DESC:
-					strcpy(token[0], ".TP\n");
+					um_strcpy(token[0], ".TP\n", MAX_TOKEN_LEN+1, "c_item[16]");
 					if (token[1][0]=='[')
 					{	add_description();
 						replace_once(token[0], "[", ".B ");
@@ -2032,7 +2032,7 @@ GLOBAL void c_item ( void )
 					{	add_description();
 						replace_once(token[0], "[", BOLD_ON);
 						replace_last(token[0], "]", BOLD_OFF);
-						strcpy(sBig, token[0]);
+						um_strcpy(sBig, token[0], 1024, "c_item[17]");
 						if (desttype==TORTF)
 						{	c_rtf_styles(sBig);
 							c_rtf_quotes(sBig);
@@ -2057,7 +2057,7 @@ GLOBAL void c_item ( void )
 					{	add_description();
 						delete_once(token[0], "[");
 						delete_last(token[0], "]");
-						strcpy(sBig, token[0]);
+						um_strcpy(sBig, token[0], 1024, "c_item[18]");
 						if (desttype==TORTF)
 						{	c_rtf_styles(sBig);
 							c_rtf_quotes(sBig);
@@ -2109,7 +2109,7 @@ GLOBAL void c_item ( void )
 			}
 			
 			if ( insert_placeholder(sBig, sBig, sBig, sBig) )
-			{	strcpy(token[0], sBig);
+			{	um_strcpy(token[0], sBig, MAX_TOKEN_LEN+1, "c_item[19]");
 			}
 			else
 			{	token[0][0]= EOS;
@@ -2135,17 +2135,17 @@ GLOBAL void c_item ( void )
 					{	add_description();
 						replace_once(token[0], "[", BOLD_ON);
 						replace_last(token[0], "]", BOLD_OFF);
-						strcpy(sBig, token[0]);
+						um_strcpy(sBig, token[0], 1024, "c_item[20]");
 						replace_udo_quotes(sBig);
 						if (!bDocAutorefItemsOff)
 						{	auto_references(sBig, FALSE, "", 0, 0);
 						}
 						c_internal_styles(sBig);
 			 			strinsert(sBig, "<dt>");
-						strcat(sBig, "</dt><dd>");
+						um_strcat(sBig, "</dt><dd>", 1024, "c_item[21]");
 					}
 					else
-					{	strcpy(sBig, "<dt>&nbsp;</dt><dd>");
+					{	um_strcpy(sBig, "<dt>&nbsp;</dt><dd>", 1024, "c_item[22]");
 					}
 					break;
 
@@ -2177,7 +2177,7 @@ GLOBAL void c_item ( void )
 								break;
 								
 						}
-						strcpy(sBig, token[0]);
+						um_strcpy(sBig, token[0], 1024, "c_item[23]");
 						replace_udo_quotes(sBig);
 						if (!bDocAutorefItemsOff)
 						{	auto_references(sBig, FALSE, "", 0, 0);
@@ -2202,7 +2202,7 @@ GLOBAL void c_item ( void )
 			}
 			
 			if ( insert_placeholder(sBig, sBig, sBig, sBig) )
-			{	strcpy(token[0], sBig);
+			{	um_strcpy(token[0], sBig, MAX_TOKEN_LEN+1, "c_item[24]");
 			}
 			else
 			{	token[0][0]= EOS;
@@ -2215,7 +2215,7 @@ GLOBAL void c_item ( void )
 		 	{
 		 		case ENV_ITEM:
 				case ENV_ENUM:
-		 		{	strcpy(token[0], "<item>");
+		 		{	um_strcpy(token[0], "<item>", MAX_TOKEN_LEN+1, "c_item[25]");
 					break;
 		 		}
 		 		
@@ -2226,16 +2226,16 @@ GLOBAL void c_item ( void )
 						delete_once(token[0], "[");
 						delete_last(token[0], "]");
 						strinsert(token[0], "<tag>");
-						strcat(token[0], "</tag>");
+						um_strcat(token[0], "</tag>", MAX_TOKEN_LEN+1, "c_item[26]");
 					}
 					else
-					{	strcpy(token[0], "<tag> </tag>");
+					{	um_strcpy(token[0], "<tag> </tag>", MAX_TOKEN_LEN+1, "c_item[27]");
 					}
 					break;
 		 		}	/* TOLDS: ENV_DESC */
 		 		
 				case ENV_LIST:	/* Hier genau wie bei ASCII */
-				{	strcpy(token[0], " ");
+				{	um_strcpy(token[0], " ", MAX_TOKEN_LEN+1, "c_item[28]");
 					
 					if (token[1][0]=='[')
 					{	add_description();
@@ -2246,13 +2246,13 @@ GLOBAL void c_item ( void )
 					ll= iEnvIndent[iEnvLevel]-2;	/* Die 2 Leerzeichen Ausgleich oben hier beruecksichtigen! */
 					tl= toklen(token[0]);
 					while ( (int) tl <= ll)
-					{	strcat(token[0], " ");
+					{	um_strcat(token[0], " ", MAX_TOKEN_LEN+1, "c_item[29]");
 						tl++;
 					}
 
 					strcpy_prev_indent(li);
 					sprintf(s, "%s%s", li, token[0]);
-					strcpy(token[0], s);
+					um_strcpy(token[0], s, MAX_TOKEN_LEN+1, "c_item[30]");
 					break;
 				}	/* TOLDS: ENV_LIST */
 			}
@@ -2264,25 +2264,25 @@ GLOBAL void c_item ( void )
 		 	{
 		 		case ENV_ITEM:
 				case ENV_ENUM:
-		 		{	strcpy(token[0], "<item>");
+		 		{	um_strcpy(token[0], "<item>", MAX_TOKEN_LEN+1, "c_item[31]");
 					break;
 		 		}
 		 		
 				case ENV_DESC:
-		 		{	strcpy(token[0], "<item>");
+		 		{	um_strcpy(token[0], "<item>", MAX_TOKEN_LEN+1, "c_item[32]");
 					if (token[1][0]=='[')
 					{	add_description();
 						replace_once(token[0], "[", "<emph>");
 						replace_last(token[0], "]", "<\\emph>");
 					}
 					else
-					{	strcpy(token[0], "<item>");
+					{	um_strcpy(token[0], "<item>", MAX_TOKEN_LEN+1, "c_item[33]");
 					}
 					break;
 		 		}	/* TOHPH: ENV_DESC */
 		 		
 				case ENV_LIST:	/* Hier genau wie bei ASCII */
-				{	strcpy(token[0], " ");
+				{	um_strcpy(token[0], " ", MAX_TOKEN_LEN+1, "c_item[34]");
 					
 					if (token[1][0]=='[')
 					{	add_description();
@@ -2293,13 +2293,13 @@ GLOBAL void c_item ( void )
 					ll= iEnvIndent[iEnvLevel]-2;	/* Die 2 Leerzeichen Ausgleich oben hier beruecksichtigen! */
 					tl= toklen(token[0]);
 					while ( (int) tl <= ll )
-					{	strcat(token[0], " ");
+					{	um_strcat(token[0], " ", MAX_TOKEN_LEN+1, "c_item[35]");
 						tl++;
 					}
 
 					strcpy_prev_indent(li);
 					sprintf(s, "%s%s", li, token[0]);
-					strcpy(token[0], s);
+					um_strcpy(token[0], s, MAX_TOKEN_LEN+1, "c_item[36]");
 					break;
 				}	/* TOHPH: ENV_LIST */
 			}
@@ -2315,18 +2315,18 @@ GLOBAL void c_item ( void )
 		 		}
 		 		
 				case ENV_DESC:
-				{	strcpy(token[0], ":dt.");
+				{	um_strcpy(token[0], ":dt.", MAX_TOKEN_LEN+1, "c_item[37]");
 					if (token[1][0]=='[')
 					{	add_description();
 						replace_once(token[0], "[", BOLD_ON);
 						replace_last(token[0], "]", BOLD_OFF);
 					}
-					strcat(token[0], "\n:dd.");
+					um_strcat(token[0], "\n:dd.", MAX_TOKEN_LEN+1, "c_item[38]");
 					break;
 				}
 
 				case ENV_LIST:
-				{	strcpy(token[0], ":dt.");
+				{	um_strcpy(token[0], ":dt.", MAX_TOKEN_LEN+1, "c_item[39]");
 					if (token[1][0]=='[')
 					{	add_description();
 						switch(env_kind[iEnvLevel])
@@ -2349,7 +2349,7 @@ GLOBAL void c_item ( void )
 								break;
 						}
 					}
-					strcat(token[0], "\n:dd.");
+					um_strcat(token[0], "\n:dd.", MAX_TOKEN_LEN+1, "c_item[40]");
 					break;
 				}
 			}
@@ -2359,13 +2359,14 @@ GLOBAL void c_item ( void )
 			switch(iEnvType[iEnvLevel])
 		 	{
 		 		case ENV_ITEM:
-					strcpy(token[0], itemchar[iItemLevel]);
+					um_strcpy(token[0], itemchar[iItemLevel], MAX_TOKEN_LEN+1, "c_item[41]");
 					break;
 		 		case ENV_ENUM:
 					enum_count[iEnvLevel]++;
 					itoenum(iEnumLevel, &(enum_count[iEnvLevel]), s);
-					sprintf(token[0], ")\n(%d.) off%d writeBeforeLeft\n(",
-						enum_count[iEnvLevel], iEnvLevel);
+					/* Changed in V6.4.1 [NHz] */
+					sprintf(token[0], "%s\n%s%d.%s off%d writeBeforeLeft\n%s", KPSPC_S, KPSPO_S,
+						enum_count[iEnvLevel], KPSPC_S, iEnvLevel, KPSPO_S);
 					break;
 				/* New in r6pl15 [NHz] */
 				case ENV_DESC:
@@ -2390,10 +2391,11 @@ GLOBAL void c_item ( void )
 
 						delete_once(token[0], "[");
 						delete_last(token[0], "]");
-	 					sprintf(s, ") udoshow Bon (%s) offDesc writeBeforeLeft Boff (", token[0]);
+						/* Changed in V6.4.1 [NHz] */
+	 					sprintf(s, "%s udoshow Bon %s%s%s offDesc writeBeforeLeft Boff %s", KPSPC_S, KPSPO_S, token[0], KPSPC_S, KPSPO_S);
 
-						strcpy(token[0], s);
-						strcat(token[0], sAdd);
+						um_strcpy(token[0], s, MAX_TOKEN_LEN+1, "c_item[42]");
+						um_strcat(token[0], sAdd, MAX_TOKEN_LEN+1, "c_item[43]");
 
 					}
 					break;
@@ -2438,32 +2440,25 @@ GLOBAL void c_item ( void )
 					switch(env_kind[iEnvLevel])
 		 			{
 		 				case LIST_BOLD:
-							/* Changed in r6pl15 [NHz] */
-
-/*		 					sprintf(s, " %s%s%s%s%s", li, BOLD_ON, token[0], BOLD_OFF, ri);*/
-		 					sprintf(s, ") udoshow Bon (%s) offList offCountS get writeBeforeLeft Boff (", token[0]);
+							/* Changed in V6.4.1 [NHz] */
+		 					sprintf(s, "%s udoshow Bon %s%s%s offList offCountS get writeBeforeLeft Boff %s", KPSPC_S, KPSPO_S, token[0], KPSPC_S, KPSPO_S);
 		 					break;
 		 				case LIST_ITALIC:
-							/* Changed in r6pl15 [NHz] */
-
-/*		 					sprintf(s, " %s%s%s%s%s", li, ITALIC_ON, token[0], ITALIC_OFF, ri);*/
-		 					sprintf(s, ") udoshow %s Ion (%s) offList offCountS get writeBeforeLeft Ioff %s (", li, token[0], ri);
+							/* Changed in V6.4.1 [NHz] */
+		 					sprintf(s, "%s udoshow Ion %s%s%s offList offCountS get writeBeforeLeft Ioff %s", KPSPC_S, KPSPO_S, token[0], KPSPC_S, KPSPO_S);
 		 					break;
 		 				case LIST_TYPEWRITER:
-							/* New in r6pl15 [NHz] */
-
-		 					sprintf(s, ") udoshow %s Von (%s) offList offCountS get writeBeforeLeft Voff %s (", li, token[0], ri);
+							/* Changed in V6.4.1 [NHz] */
+		 					sprintf(s, "%s udoshow Von %s%s%s offList offCountS get writeBeforeLeft Voff  %s", KPSPC_S, KPSPO_S, token[0], KPSPC_S, KPSPO_S);
 		 					break;
 		 				default:
-							/* Changed in r6pl15 [NHz] */
-
-/*		 					sprintf(s, " %s%s%s", li, token[0], ri);*/
-		 					sprintf(s, ") udoshow %s (%s) offList offCountS get writeBeforeLeft %s (", li, token[0], ri);
+							/* Changed in V6.4.1 [NHz] */
+		 					sprintf(s, "%s udoshow %s%s%s offList offCountS get writeBeforeLeft %s", KPSPC_S, KPSPO_S, token[0], KPSPC_S, KPSPO_S);
 		 					break;
 		 			}
 
-					strcpy(token[0], s);
-					strcat(token[0], sAdd);
+					um_strcpy(token[0], s, MAX_TOKEN_LEN+1, "c_item[44]");
+					um_strcat(token[0], sAdd, MAX_TOKEN_LEN+1, "c_item[45]");
 
 					break;
 			}
@@ -2889,11 +2884,16 @@ GLOBAL void c_begin_document ( void )
 	switch (desttype)
 	{
 		case TOPDL:
-			if (titdat.author!=NULL || titdat.title!=NULL || titdat.program!=NULL )
-			{	outln("\\pdfinfo");
-				if (titdat.author!=NULL)	voutlnf("\tauthor {%s}", titdat.author);
-				if (titdat.title!=NULL)		voutlnf("\ttitle {%s}", titdat.title);
-				if (titdat.program!=NULL)	voutlnf("\tsubject {%s}", titdat.program);
+			/* Changed in r6.2pl1 [NHz] */ 			if (titdat.author!=NULL || titdat.title!=NULL || titdat.program!=NULL )
+			{	outln("\\pdfinfo {");
+				if (titdat.title!=NULL) voutlnf("  /Title (%s)", titdat.title);
+				if (titdat.author!=NULL) voutlnf("  /Author (%s)", titdat.author);
+				voutlnf("  /Creator (UDO Version %s.%s.%s for %s)", UDO_REL, UDO_SUBVER, UDO_PL, UDO_OS);
+				voutlnf("  /CreationDate (D:%d%02d%02d%02d%02d%02d)", iDateYear, iDateMonth, iDateDay, iDateHour, iDateMin, iDateSec);
+				voutlnf("  /ModDate (D:%d%02d%02d%02d%02d%02d)", iDateYear, iDateMonth, iDateDay, iDateHour, iDateMin, iDateSec);
+				if (titdat.description!=NULL) voutlnf("  /Subject (%s)", titdat.description);
+				if (titdat.keywords!=NULL) voutlnf("  /Keywords (%s)", titdat.keywords); /* Set by !docinfo [keywords] foo */
+				outln("}");
 			}
 			output_tex_environments();
 			break;
@@ -3113,7 +3113,7 @@ GLOBAL void c_begin_document ( void )
 			}
 
 			/* ---- Ueber UDO ---- */
-			voutlnf("  {\\doccomm UDO Release %s.%s Patchlevel %s}", UDO_REL, UDO_SUBVER, UDO_PL);
+			voutlnf("  {\\doccomm UDO Version %s.%s.%s}", UDO_REL, UDO_SUBVER, UDO_PL);
 
 			/* ---- Erstellungsdatum & Sonstiges ---- */
 			voutlnf("  {\\creatim\\yr%d\\mo%d\\dy%d\\hr%d\\min%d}",
@@ -3270,14 +3270,21 @@ GLOBAL void c_begin_document ( void )
 			outln("basefont setBaseFont");
 			
 			voutlnf("/Titeltext (%s %s) def", titdat.title, titdat.program);
-			voutlnf("/FootAuthor (\\251 %s) def", titdat.author);
+			/* Changed: Fixed bug #0000040 in r6.3pl16 [NHz] */
+			if(titdat.author)
+				voutlnf("/FootAuthor (\\251 %s) def", titdat.author);
+			else
+				outln("/FootAuthor () def");
 			
 			/* Document info */
 			voutlnf("[ /Title (%s %s)", titdat.title, titdat.program);
 			voutlnf("  /Author (%s)", titdat.author);
-			voutlnf("  /Subject (%s)", titdat.description);
-			voutlnf("  /Keywords (%s)", titdat.keywords); /* Set by !docinfo [keywords] foo */
-			voutlnf("  /Creator (UDO Release %s.%s Patchlevel %s for %s)", UDO_REL, UDO_SUBVER, UDO_PL, UDO_OS);
+			/* Changed: Fixed bug #0000062 in V6.4.1 [NHz] */
+			if(titdat.description)
+				voutlnf("  /Subject (%s)", titdat.description);
+			if(titdat.keywords)
+				voutlnf("  /Keywords (%s)", titdat.keywords); /* Set by !docinfo [keywords] foo */
+			voutlnf("  /Creator (UDO Version %s.%s.%s for %s)", UDO_REL, UDO_SUBVER, UDO_PL, UDO_OS);
 			voutlnf("  /CreationDate (D:%d%02d%02d%02d%02d%02d)", iDateYear, iDateMonth, iDateDay, iDateHour, iDateMin, iDateSec);
 			voutlnf("  /ModDate (D:%d%02d%02d%02d%02d%02d)", iDateYear, iDateMonth, iDateDay, iDateHour, iDateMin, iDateSec);
 			outln("/DOCINFO pdfmark\n");
@@ -3409,7 +3416,7 @@ GLOBAL void c_end_document ( void )
 				memset(n, '#', 62);	n[62]= EOS;
 				outln("");
 				voutlnf("%s  %s", sSrcRemOn, n);
-				voutlnf("    # @(#) %s%s - made with UDO Release %s.%s Patchlevel %s for %s",
+				voutlnf("    # @(#) %s%s - made with UDO Version %s.%s.%s for %s",
 					outfile.name, outfile.suff, UDO_REL, UDO_SUBVER, UDO_PL, UDO_OS);
 				voutlnf("    %s %s", n, sSrcRemOff);
 			}
@@ -3429,9 +3436,9 @@ GLOBAL void c_end_document ( void )
 				outln("/acty acty 50 sub def");
 				outln("actx acty moveto");
 				if(destlang == TOGER)
-					voutlnf("(Release %s.%s Patchlevel %s) (%s) (%s) aboutUDO_ger", UDO_REL, UDO_SUBVER, UDO_PL, UDO_OS, UDO_URL);
+					voutlnf("(Version %s.%s.%s) (%s) (%s) aboutUDO_ger", UDO_REL, UDO_SUBVER, UDO_PL, UDO_OS, UDO_URL);
 				else
-					voutlnf("(Release %s.%s Patchlevel %s) (%s) (%s) aboutUDO_eng", UDO_REL, UDO_SUBVER, UDO_PL, UDO_OS, UDO_URL);
+					voutlnf("(Version %s.%s.%s) (%s) (%s) aboutUDO_eng", UDO_REL, UDO_SUBVER, UDO_PL, UDO_OS, UDO_URL);
 				outln("newpage");
 			}
 			break;
@@ -3605,14 +3612,11 @@ GLOBAL void init_env_itemchar ( void )
 			break;
 
 		case TOKPS:
-			strcpy(itemchar[1], ")\n/bullet off1 writeBulletLeft\n(");
-			/* Changed in r6pl15 [NHz] */
-/*			strcpy(itemchar[2], ")\n/dagger off2 writeBulletLeft\n(");*/
-			strcpy(itemchar[2], ")\n/endash off2 writeBulletLeft\n(");
-/*			strcpy(itemchar[3], ")\n/bullet off3 writeBulletLeft\n(");*/
-			strcpy(itemchar[3], ")\n/asterix off3 writeBulletLeft\n(");
-/*			strcpy(itemchar[4], ")\n/bullet off4 writeBulletLeft\n(");*/
-			strcpy(itemchar[4], ")\n/periodcentered off4 writeBulletLeft\n(");
+			/* Changed in V6.4.1 [NHz] */
+			sprintf(itemchar[1], "%s\n/bullet off1 writeBulletLeft\n%s", KPSPC_S, KPSPO_S);
+			sprintf(itemchar[2], "%s\n/endash off1 writeBulletLeft\n%s", KPSPC_S, KPSPO_S);
+			sprintf(itemchar[3], "%s\n/asterix off1 writeBulletLeft\n%s", KPSPC_S, KPSPO_S);
+			sprintf(itemchar[4], "%s\n/periodcentered off1 writeBulletLeft\n%s", KPSPC_S, KPSPO_S);
 			strcpy(itemchar[5], itemchar[1]);
 			strcpy(itemchar[6], itemchar[2]);
 			break;
