@@ -835,7 +835,11 @@ GLOBAL void c_bmp_output ( const char *name, const char *caption, const BOOLEAN
 	{
 		case TORTF:	/*r6pl6*/
 			if ( !get_bmpheader(datei, &bmpheader) )
-			{	error_read_bmp(datei);
+			{	/* Fixed bug #0000017 in V6.4.1 [NHz] */
+				if(strstr(datei, BMP_MW_NAME) != NULL)
+					error_read_bmp(BMP_MW_NAME);
+				else
+					error_read_bmp(datei);
 				bErrorDetected= TRUE;
 				return;
 			}
@@ -847,7 +851,8 @@ GLOBAL void c_bmp_output ( const char *name, const char *caption, const BOOLEAN
 			}
 
 			uc4ToInt(bmpheader.biWidth, &width);
-			uc4ToInt(bmpheader.biWidth, &height);
+			/* Fixed bug #0000056 in V6.4.1 [NHz] */
+			uc4ToInt(bmpheader.biHeight, &height);
 			uc2ToInt(bmpheader.biBitCnt, &bitcnt);
 			uc2ToInt(bmpheader.biPlanes, &planes);
 
@@ -912,8 +917,8 @@ GLOBAL void c_bmp_output ( const char *name, const char *caption, const BOOLEAN
 					/* sprintf(n, "%s %d: %s", lang.figure, image_counter, caption); */
 					/* removed parenthesis */
 
-					/* New in r6pl16 [NHz] */
-					sprintf(n, "{{\\*\\bkmkstart _tocimg%d}%s }{\\field{\\*\\fldinst {SEQ %s \\\\* ARABIC }}: %s{\\fldrslt %d: %s{\\*\\bkmkend _Tocimg%d}}}", image_counter, lang.figure, lang.figure, caption, image_counter, caption, image_counter);
+					/* Fixed bug #0000056 in V6.4.1 [NHz] */
+					sprintf(n, "{{\\*\\bkmkstart _tocimg%d}%s }{\\field{\\*\\fldinst {SEQ %s \\\\* ARABIC }}{\\fldrslt %d}}: %s{\\*\\bkmkend _Tocimg%d}", image_counter, lang.figure, lang.figure, image_counter, caption, image_counter);
 				}
 				else
 				{	/* Changed in r6pl16 [NHz] */
@@ -1369,7 +1374,8 @@ GLOBAL void c_png_output ( const char *name, const char *caption, const char *su
 #endif
 
 	outln("\\mbox{");
-	voutlnf("\\pdfimage %s", datei);
+	/* Changed in V6.4.1 [NHz] */
+	voutlnf("\\pdfximage{%s}\\pdfrefximage\\pdflastximage", datei);
 	outln("}");
 
 	if ( caption[0]!=EOS )
@@ -1403,7 +1409,7 @@ GLOBAL void set_image_alignment ( void )
 {
 	char s[256];
 
-	tokcpy2(s);
+	tokcpy2(s, 256);
 
 	if (strstr(s, "center")!=NULL)
 	{	image_alignment= ALIGN_CENT;
