@@ -92,6 +92,29 @@ GLOBAL void logln ( const char *s )
 	fprintf(fLogfile, "%s\n", s);
 }	/* logln */
 
+/*	----------------------------------------------------------------------
+	Ausgabe ins Logfile und via printf inklusive Datei und Zeilennummer
+	[vj] v6.3.7 hinzugefgt zu debuggingzwecken
+	----------------------------------------------------------------------	*/
+GLOBAL void loglnposprintf ( const char *we, const char *msg )
+{
+	char z[512];
+	
+	sprintf(z, "%s: %s %u: %s",
+		we,
+		sCurrFileName,
+		uiCurrFileLine,
+		msg
+	);
+	logln(z);
+
+#ifdef USE_LOGLNPOSPRINTF
+	printf("%s\n", z);
+#else
+	show_logln_message(z);	/* r6pl12: Ausgabe ans GUI weiterreichen */
+#endif
+	
+}	/* loglnpos */
 
 /*	----------------------------------------------------------------------
 	Ausgabe ins Logfile inklusive Datei und Zeilennummer
@@ -391,8 +414,14 @@ GLOBAL void error_read_img ( const char *s )
 }
 
 GLOBAL void error_read_bmp ( const char *s )
-{	error_msg_para("couldn't read BMP header of <%s>", s);
-	errno_logln(s);
+{	/* Fixed bug #0000017 in V6.4.1 [NHz] */
+	if(strcmp(s, BMP_MW_NAME) == 0)
+		note_msg_solo("Image for UDO link generated (see below), please translate again to complete");
+	else
+	{
+		error_msg_para("couldn't read BMP header of <%s>", s);
+		errno_logln(s);
+	}
 }
 
 GLOBAL void error_read_pcx ( const char *s )
