@@ -42,7 +42,7 @@ const char *id_par_c= "@(#) par.c       19.07.1999";
 
 #include "export.h"
 #include "par.h"
-
+#include "udomem.h"
 
 
 /*	############################################################
@@ -384,7 +384,7 @@ GLOBAL void reset_speccmds ( void )
 		for (i=0; i<speccmd_counter; i++)
 		{
 			if ( speccmd[i].entry!=NULL )
-			{	free(speccmd[i].entry);
+			{	um_free(speccmd[i].entry);
 				speccmd[i].entry= NULL;
 			}
 			
@@ -408,7 +408,7 @@ GLOBAL BOOLEAN add_speccmd ( char *entry )
 		speccmd_counter++;
 
 		sl= strlen(entry);
-		ptr= (char *) ( malloc(sl*sizeof(char)+1) );
+		ptr= (char *) ( um_malloc(sl*sizeof(char)+1) );
 		if (ptr==NULL)
 		{	error_malloc_failed();
 			speccmd_counter--;
@@ -499,12 +499,12 @@ GLOBAL void reset_placeholders ( void )
 		for (i=0; i<phold_counter; i++)
 		{
 			if ( phold[i].entry!=NULL )
-			{	free(phold[i].entry);
+			{	um_free(phold[i].entry);
 				phold[i].entry= NULL;
 			}
 			
 			if ( phold[i].text!=NULL )
-			{	free(phold[i].text);
+			{	um_free(phold[i].text);
 				phold[i].text= NULL;
 			}
 			
@@ -528,7 +528,7 @@ GLOBAL BOOLEAN add_placeholder ( char *entry, char *rawtext )
 		phold_counter++;
 
 		el= strlen(entry);
-		eptr= (char *) ( malloc(el*sizeof(char)+1) );
+		eptr= (char *) ( um_malloc(el*sizeof(char)+1) );
 		if (eptr==NULL)
 		{	error_malloc_failed();
 			phold_counter--;
@@ -536,10 +536,10 @@ GLOBAL BOOLEAN add_placeholder ( char *entry, char *rawtext )
 		}
 		
 		tl= strlen(rawtext);
-		tptr= (char *) ( malloc (tl*sizeof(char)+1) );
+		tptr= (char *) ( um_malloc (tl*sizeof(char)+1) );
 		if (tptr==NULL)
 		{	error_malloc_failed();
-			free(eptr);
+			um_free(eptr);
 			phold_counter--;
 			return FALSE;
 		}
@@ -834,7 +834,8 @@ LOCAL BOOLEAN convert_link_pdf ( char *s, const char *p0, char *p1, char *p2, co
 		else
 		{	dest= li;
 		}
-		sprintf(s_entry, "{\\leavevmode\\pdfannotlink goto num %d\n%s\\pdfendlink}",
+		/* Changed in r6.2pl1 [NHz] */
+		sprintf(s_entry, "{\\pdfstartlink goto num %d\n%s\\pdfendlink}",
 			dest, p1);
 	}
 	else
@@ -991,6 +992,12 @@ LOCAL BOOLEAN convert_link_ps ( char *s, const char *p0, char *p1, char *p2, con
 		}
 		replace_udo_quotes(p2);	/* r6pl2 */
 		replace_udo_quotes(p1);	/* r6pl2 */
+		/* Changed in V6.4.1 [NHz] */
+		replace_all(p1, "(", "\\(");
+		replace_all(p1, ")", "\\)");
+		c_vars(p1);
+		qreplace_all(p1, KPSPC_S, KPSPC_S_LEN, ")", 1);
+		qreplace_all(p1, KPSPO_S, KPSPO_S_LEN, "(", 1);
 		sprintf(s_entry, ") udoshow (%s) /%s 0 255 0 Link (", p1, p2);
 	}
 
@@ -1028,7 +1035,8 @@ LOCAL BOOLEAN convert_link_etc ( char *s, const char *p0, char *p1, char *p2, co
 	replace_udo_tilde(p2);
 	replace_udo_nbsp(p2);
 
-	convert_tilde(p1);
+	/* Deleted in r6.2pl1 [NHz] / Bug #00000030 */
+	/* 	convert_tilde(p1); */
 	replace_udo_quotes(p1);
 
 	if (flag)
@@ -1039,7 +1047,7 @@ LOCAL BOOLEAN convert_link_etc ( char *s, const char *p0, char *p1, char *p2, co
 		}
 		else
 		{	if (desttype==TORTF)	/*r6pl6: die richtigen benutzen */
-			{	strcpy(lq, "\\ldblquote");
+			{	strcpy(lq, "\\ldblquote ");
 				strcpy(rq, "\\rdblquote");
 			}
 			else
@@ -1232,8 +1240,8 @@ LOCAL void c_url ( char *s, BOOLEAN inside_b4_macro )
 	/* Changed in r6pl17 [NHz] / s_entry (1024 to 4096 bytes), url_rtf (512 to 2048 bytes) */
 	char s_entry[4096], url_rtf[2048], rtf0[4];
 
-	char rtf1[]="00d0c9ea79f9bace118c8200aa004ba90b0200000017000000";
-	char rtf2[]="0000e0c9ea79f9bace118c8200aa004ba90b";
+	char rtf1[]="00d0c9ea79f9bace118c8200aa004ba90b0200000003000000";
+	char rtf2[]="e0c9ea79f9bace118c8200aa004ba90b";
 	char rtf3[]="000000";
 	char rtf4[]="0000";
 	BOOLEAN linkerror= FALSE;
@@ -1245,7 +1253,7 @@ LOCAL void c_url ( char *s, BOOLEAN inside_b4_macro )
 		/* Wird ein leerer Parameter benutzt, den	*/
 		/* den ersten auch als zweiten verwenden.	*/
 		if (Param[2][0]==EOS)
-		{	strcpy(Param[2], Param[1]);
+		{	um_strcpy(Param[2], Param[1], 1024, "c_url[1]");
 		}
 
 		if (inside_b4_macro)
@@ -1268,7 +1276,7 @@ LOCAL void c_url ( char *s, BOOLEAN inside_b4_macro )
 				case TOMHH:
  					convert_tilde(Param[1]);
 					if (Param[2][0]==EOS)
-					{	strcpy(Param[2], Param[1]);
+					{	um_strcpy(Param[2], Param[1], 1024, "c_url[TOHTM|1]");
 					}
 					replace_udo_quotes(Param[2]);	/* r6pl2 */
 					replace_udo_quotes(Param[1]);	/* r6pl2 */
@@ -1278,6 +1286,10 @@ LOCAL void c_url ( char *s, BOOLEAN inside_b4_macro )
 					else
 					{	sprintf(s_entry, "<a href=\"%s\">%s</a>", Param[2], Param[1]);
 					}
+					if (strlen(s_entry)>=4096) /* vj: For debugging reasons */
+					{
+						printf("c_url: s_entry buffer overrus after sprintf\n");
+					}
  					linkerror= !insert_placeholder(s, Param[0], s_entry, Param[1]);
  					break;
 
@@ -1290,14 +1302,19 @@ LOCAL void c_url ( char *s, BOOLEAN inside_b4_macro )
 					}
 					replace_udo_quotes(Param[2]);
 					replace_udo_quotes(Param[1]);
+					/* Changed in V6.4.1 [NHz] */
+					c_divis(Param[1]);
+					c_vars(Param[1]);
+					/* Changed: Fixed bug #0000062 in V 6.4.1 [NHz] */
+					node2postscript(Param[1], KPS_CONTENT);
+					replace_all(Param[1], KPSPO_S, "(");
+					replace_all(Param[1], KPSPC_S, ")");
 					sprintf(s_entry, ") udoshow (%s) (%s) 0 0 255 WebLink (", Param[1], Param[2]);
    				linkerror= !insert_placeholder(s, Param[0], s_entry, Param[1]);
 					break;
 
-					/* New in r6pl15 [NHz] */
-					/* Weblink for WinHelp */
-				case TOWIN:
-
+					/* Deleted bug in V6.4.1 [NHz] */
+					/* Weblink for WinHelp4 */
 				case TOWH4:
   				convert_tilde(Param[1]);
 					if (Param[2][0]==EOS)
@@ -1305,7 +1322,7 @@ LOCAL void c_url ( char *s, BOOLEAN inside_b4_macro )
 					}
 					replace_udo_quotes(Param[2]);
 					replace_udo_quotes(Param[1]);
-					sprintf(s_entry, "{\\ul (%s)}{\\v !ExecFile((%s))}", Param[1], Param[2]);
+					sprintf(s_entry, "{\\ul %s}{\\v !ExecFile(%s)}", Param[1], Param[2]);
    				linkerror= !insert_placeholder(s, Param[0], s_entry, Param[1]);
 					break;
 
@@ -1313,30 +1330,31 @@ LOCAL void c_url ( char *s, BOOLEAN inside_b4_macro )
 					/* Weblink for Richtext Format */
 				case TORTF:
   				convert_tilde(Param[1]);
+
+					/* New in r6.2pl1 [NHz] / Bug #00000029 */
+					c_rtf_quotes(Param[1]);
+
 					if (Param[2][0]==EOS)
 					{	strcpy(Param[2], Param[1]);
 					}
 					replace_udo_quotes(Param[2]);
 					replace_udo_quotes(Param[1]);
 
-
-					url_len = (int)strlen(Param[2]);
+					/* Changed in r6.2pl1 [NHz] */ 					auto_quote_chars(Param[2], TRUE); 					url_len = (int)strlen(Param[2]);
 
 					rtf0[0]=EOS;
-
 					url_rtf[0]=EOS;
 
 					for(i=0;i<url_len;i++)
-
-					{	sprintf(rtf0, "%x", (int)Param[2][i]);
-
+					{	if(Param[2][i] == '\\') 						{	i += 2;
+							rtf0[0]=EOS;
+							strncpy(rtf0, Param[2]+i, 2);
+							i++; 						} 						else 							sprintf(rtf0, "%x", (int)Param[2][i]); 
 						strcat(url_rtf, rtf0);
-
 						strcat(url_rtf, "00");
-
 					}
 
-					sprintf(s_entry, "{\\field{\\*\\fldinst {HYPERLINK \"%s\"}{{\\*\\datafield %s%x%s%s%s%x%s%s%s}}}\n{\\fldrslt {\\cs15\\ul\\cf2 %s}}}", Param[2], rtf1, url_len+1, rtf3, url_rtf, rtf2, (url_len+2)*2, rtf3, url_rtf, rtf4, Param[1]);
+					sprintf(s_entry, "{\\field{\\*\\fldinst {HYPERLINK \"%s\"}{{\\*\\datafield %s%s%x%s%s%s}}}\n{\\fldrslt {\\cs15\\ul\\cf2 %s}}}", Param[2], rtf1, rtf2, (url_len+1)*2, rtf3, url_rtf, rtf4, Param[1]);
 
    				linkerror= !insert_placeholder(s, Param[0], s_entry, Param[1]);
 					break;
@@ -1488,6 +1506,10 @@ LOCAL void c_xlink ( char *s, BOOLEAN inside_b4_macro )
 						}
 						replace_udo_quotes(Param[2]);	/* r6pl2 */
 						replace_udo_quotes(Param[1]);	/* r6pl2 */
+						/* Changed in V6.4.1 [NHz] */
+						c_divis(Param[1]);
+						c_vars(Param[1]);
+						auto_quote_chars(Param[1], TRUE);
 						sprintf(s_entry, ") udoshow (%s) (%s) %s 255 0 0 FileLink (", Param[1], Param[2], "/Null");
    					linkerror= !insert_placeholder(s, Param[0], s_entry, Param[1]);
 						break;
@@ -1663,6 +1685,10 @@ LOCAL void c_ilink ( char *s, const BOOLEAN inside_b4_macro )
 			case TOTVH:
 				linkerror= !convert_link_tvh(s, Param[0], Param[2], Param[3]);
 				break;
+			/* New in V6.4.1 [NHz] */
+			case TOKPS:
+				linkerror= !convert_link_ps(s, Param[0], Param[2], Param[3], link);
+				break;
 			default:
 				linkerror= !convert_link_etc(s, Param[0], Param[2], Param[3], link);
 				break;
@@ -2723,6 +2749,19 @@ LOCAL void c_internal_image ( char *s, const BOOLEAN inside_b4_macro )
 				}
 				flag= !insert_placeholder(s, Param[0], s_entry, Param[2]);
 				break;
+			/* New in r6.3pl3 [NHz] */
+			case TORTF:
+				strcpy(s_entry, "");
+				flag= !insert_placeholder(s, Param[0], s_entry, Param[2]);
+				break;
+			/* New in V6.4.1 [NHz] */
+			case TOKPS:
+				strcpy(s_entry, Param[2]);
+				c_vars(s_entry);
+				replace_all(s_entry, KPSPC_S, ")");
+				replace_all(s_entry, KPSPO_S, "(");
+				flag= !insert_placeholder(s, Param[0], s_entry, Param[2]);
+				break;
 			default:
 				strcpy(s_entry, Param[2]);
 				flag= !insert_placeholder(s, Param[0], s_entry, Param[2]);
@@ -2919,15 +2958,15 @@ GLOBAL void add_hyphen ( void )
 		return;
 	}
 	
-	p= (HYPHEN *) malloc(sizeof(HYPHEN));
+	p= (HYPHEN *) um_malloc(sizeof(HYPHEN));
 	
 	if (p==NULL)
 	{	error_malloc_failed();
 		return;
 	}
 
-	tokcpy2(p->hyphen);
-	tokcpy2(p->solo);
+	tokcpy2(p->hyphen, HYPHEN_LEN+1);
+	tokcpy2(p->solo, HYPHEN_LEN+1);
 
 	if (desttype==TOTEX || desttype==TOPDL)
 	{	/* Die Tokens sind leider vorher schon durch c_vars gelaufen */
@@ -3019,7 +3058,7 @@ GLOBAL BOOLEAN add_macro ( void )
 		return FALSE;
 	}
 
-	p= (MACROS *) malloc(sizeof(MACROS));
+	p= (MACROS *) um_malloc(sizeof(MACROS));
 	
 	if (p==NULL)
 	{	error_malloc_failed();
@@ -3030,9 +3069,9 @@ GLOBAL BOOLEAN add_macro ( void )
 
 	if (token_counter>=2)
 	{	for (i=2; i<token_counter; i++)
-		{	strcat(entry, token[i]);
+		{	um_strcat(entry, token[i], 512, "add_macro[1]");
 			if (i<token_counter-1)
-			{	strcat(entry, " ");
+			{	um_strcat(entry, " ", 512, "add_macro[2]");
 			}
 		}
 	}
@@ -3047,15 +3086,15 @@ GLOBAL BOOLEAN add_macro ( void )
 	/* PL10: Inhalt zu lang? */
 	if (strlen(entry)>MACRO_CONT_LEN)
 	{	error_long_macro_cont(MACRO_CONT_LEN);
-		free(p);
+		um_free(p);
 		return FALSE;
 	}
 
-	strcpy(p->entry, entry);
+	um_strcpy(p->entry, entry, MACRO_CONT_LEN+1, "add_macro[3]");
 
 	if ( md_uses_parameters(p->entry) )	/* PL8 */
 	{	/* Makro mit Parametern */
-		strcpy(p->name, token[1]);
+		um_strcpy(p->name, token[1], MACRO_NAME_LEN+1, "add_macro[4]");
 		p->vars= TRUE;
 	}
 	else
@@ -3126,7 +3165,7 @@ GLOBAL BOOLEAN add_define ( void )
 	}
 
 
-	p= (DEFS *) malloc(sizeof(DEFS));
+	p= (DEFS *) um_malloc(sizeof(DEFS));
 	
 	if (p==NULL)
 	{	error_malloc_failed();
@@ -3137,9 +3176,9 @@ GLOBAL BOOLEAN add_define ( void )
 
 	if (token_counter>=2)
 	{	for (i=2; i<token_counter; i++)
-		{	strcat(entry, token[i]);
+		{	um_strcat(entry, token[i], 512, "add_define[1]");
 			if (i<token_counter-1)
-			{	strcat(entry, " ");
+			{	um_strcat(entry, " ", 512, "add_define[2]");
 			}
 		}
 	}
@@ -3147,17 +3186,17 @@ GLOBAL BOOLEAN add_define ( void )
 	/* PL10: Inhalt zu lang? */
 	if (strlen(entry)>DEFINE_CONT_LEN)
 	{	error_long_define_cont(DEFINE_CONT_LEN);
-		free(p);
+		um_free(p);
 		return FALSE;
 	}
 	
-	strcpy(p->entry, entry);
+	um_strcpy(p->entry, entry, MACRO_CONT_LEN+1, "add_define[3]");
 
 	/* Schauen, ob der !define Parameter enthalten soll */
 
 	if ( md_uses_parameters(p->entry) )	/* PL12 */
 	{	/* Definition mit Parametern */
-		strcpy(p->name, token[1]);
+		um_strcpy(p->name, token[1], MACRO_NAME_LEN+1, "add_define[4]");
 		p->vars= TRUE;
 	}
 	else
@@ -3207,25 +3246,32 @@ GLOBAL void init_module_par ( void )
 
 GLOBAL void exit_module_par ( void )
 {
-	int	i;
+	/*
+        r6.3.19[vj]: Der folgende Code wurde auskommentiert, um zu berprfen,
+        ob sich hieraus ein Geschwindigkeitsvorteil erlangen lt. Wird der
+        Speicher hier nicht freigegeben, wird das spter um_exit tun,
+        das die Speicherbereiche viel effizienter freigeben kann.
+        Bitte nicht lschen, da er spter vielleicht wieder rein kommt!
+
+        int	i;
 
 	for (i=MAXMACROS-1; i>=0; i--)
 	{	if (macros[i]!=NULL)
-		{	free(macros[i]);
+		{	um_free(macros[i]);
 		}
 	}
 
 	for (i=MAXDEFS-1; i>=0; i--)
 	{	if (defs[i]!=NULL)
-		{	free(defs[i]);
+		{	um_free(defs[i]);
 		}
 	}
 
 	for (i=MAXHYPHEN-1; i>=0; i--)
 	{	if (hyphen[i]!=NULL)
-		{	free(hyphen[i]);
+		{	um_free(hyphen[i]);
 		}
-	}
+	}*/
 
 	reset_placeholders();
 
