@@ -34,6 +34,90 @@ const char *id_str_c= "@(#) str.c       10.03.1997";
 #include "str.h"
 #include "version.h"
 
+#include "msg.h"
+
+/*
+	#################################################################
+	#
+	# strcat und strcpy Wrapper, die Puffergrenzen checken knnen
+	#
+	#################################################################
+*/
+
+GLOBAL char *um_strcpy(char *dest, const char *src, size_t max, const char *place)
+{
+	char errbuf[120];
+	size_t slen; /* Temporre Variable, fr die Lnge von src */
+	
+	slen=(size_t)strlen(src); /* Stringlnge bestimmen */
+	if (((size_t)slen+1)<max) /* Testen obs  */
+	{
+		return strcpy(dest, src);
+	}
+	else
+	{
+		dest[0]=EOS;
+		sprintf(errbuf, "um_strcpy: buffer overrun prevented: %s: %d>%d", place, slen+1, max);
+		loglnposprintf ("Warning", errbuf);
+		return dest;
+	}
+}
+
+GLOBAL char *um_strncpy(char *dest, const char *src, size_t n, size_t max, const char *place)
+{
+	char errbuf[120];
+	if ((n+1)<max)
+	{
+		return strncpy(dest, src, n);
+	}
+	else
+	{
+		dest[0]=EOS;
+		sprintf(errbuf, "um_strncpy: buffer overrun prevented: %s: %d>%d", place, n+1, max);
+		loglnposprintf ("Warning", errbuf);
+		return dest;
+	}
+}
+
+GLOBAL char *um_strcat(char *dest, const char *src, size_t max, const char *place)
+{
+	char errbuf[120];
+	size_t dlen, slen;
+
+	dlen=(size_t)strlen(dest);
+	slen=(size_t)strlen(src);
+	
+	if ((dlen+slen+1)<max)
+	{
+		return strcat(dest, src);
+	}
+	else
+	{
+		dest[0]=EOS;
+		sprintf(errbuf, "um_strcat: buffer overrun prevented: %s: %d>%d", place, dlen+slen+1, max);
+		loglnposprintf ("Warning", errbuf);
+		return dest;
+	}
+}
+
+GLOBAL char *um_strncat(char *dest, const char *src, size_t n, size_t max, const char *place)
+{
+	char errbuf[120];
+	size_t dlen;
+
+	dlen=strlen(dest);
+	if ((dlen+n+1)<max)
+	{
+		return strncat(dest, src, n);
+	}
+	else
+	{
+		dest[0]=EOS;
+		sprintf(errbuf, "um_strncat: buffer overrun prevented: %s: %d>%d", place, dlen+n+1, max);
+		loglnposprintf("Warning", errbuf);
+		return dest;
+	}
+}
 
 /*	############################################################
 	#
@@ -478,24 +562,27 @@ GLOBAL void del_whitespaces ( char *s)
 	
 	/* Neue Methode: schneller */
 	
-	char *p1st= s;
+	char *p1st = s;
 	
-	while (*p1st!=EOS && (*p1st==' ' || *p1st=='\t') )
-	{	p1st++;
+	while (*p1st != EOS && (*p1st == ' ' || *p1st == '\t') )
+	{	++p1st;
 	}
+
+	sl = strlen(p1st);
 	
-	if (*p1st!=EOS)
-	{	sl= strlen(p1st);
+	if (*p1st != EOS && s != p1st)
+	{	
 		memmove(s, p1st, sl+1);
 	}
 	
 	/* Rechts TAB's und Leerzeichen entfernen */
-	sl= strlen(s);
-	while (	(sl>0) && ((s[sl-1]==' ') || (s[sl-1]=='\t')) )
-	{	s[sl-1]=EOS;
-		sl--;
+	if (sl > 0)
+	{
+		p1st = s + sl - 1;
+		while (*p1st == ' ' || *p1st == '\t')
+			--p1st;
+		p1st[1] = EOS;
 	}
-
 }	/*del_whitespaces*/
 
 
