@@ -45,7 +45,7 @@ const char *id_tab_c= "@(#) tab.c       10.07.1999";
 
 #include "export.h"
 #include "tab.h"
-
+#include "udomem.h"
 
 /*	############################################################
 	# lokale Variablen
@@ -122,7 +122,7 @@ GLOBAL void table_reset ( void )
 	for (y=0; y<MAX_TAB_H; y++)
 	{	for (x=0; x<MAX_TAB_W; x++)
 		{	if (tab_cell[y][x]!=NULL)
-			{	free(tab_cell[y][x]);
+			{	um_free(tab_cell[y][x]);
 				tab_cell[y][x]= NULL;
 			}
 		}
@@ -144,7 +144,7 @@ LOCAL void convert_table_caption ( const BOOLEAN visible )
 {
 	char n[512];
 	
-	tokcpy2(n);
+	tokcpy2(n, 512);
 
 	tab_caption[0]= EOS;	
 	strncat(tab_caption, n, MAXTABCAPTION);
@@ -178,7 +178,7 @@ GLOBAL void table_get_header ( char *s )
 	str2tok(s);
 	
 	if (token_counter>0)
-	{	strcpy(n, token[1]);
+	{	um_strcpy(n, token[1], 128, "table_get_header[1]");
 	}
 	
 	tab_toplines= 0;
@@ -228,8 +228,12 @@ GLOBAL BOOLEAN table_add_line ( char *s )
 
 	del_whitespaces(s);
 
-	/* Leerzeilen nicht bearbeiten */
-	if ( s[0]==EOS )
+        /* Leerzeilen  und Kommentare nicht bearbeiten */
+        /* [GS] r6pl17 Start */
+        if ( s[0]==EOS || s[0] == '#')
+        /* Ende; alt:
+        if ( s[0]==EOS )
+        */
 	{	return TRUE;
 	}
 
@@ -336,7 +340,7 @@ GLOBAL BOOLEAN table_add_line ( char *s )
 			{	tab_cell_w[x]= tl;
 			}
 	
-			ptr= (char *) (malloc(sl+2));
+			ptr= (char *) (um_malloc(sl+2));
 			if (ptr==NULL)
 			{	error_malloc_failed();
 				return FALSE;
@@ -588,9 +592,10 @@ LOCAL void table_output_rtf ( void )
 		{	out("\\ql \\cell");
 		}
 		if (tab_caption_visible)
-		{	sprintf(f, "\\qc %s %d: %s\\cell\\row\\pard",
+		/* Changed in r6.3pl3 [NHz] */
+		{	sprintf(f, "\\qc %s {\\field{\\*\\fldinst { SEQ Tabelle \\\\* ARABIC }}{\\fldrslt %d}}: %s\\cell\\row\\pard",
 							lang.table, tab_counter, tab_caption);
-		}
+		} /* added closing bracket in order to get this compiled in MXVC++ r6.3.4 [vj] */
 		else
 		{	sprintf(f, "\\qc %s\\cell\\row\\pard", tab_caption);
 		}
@@ -785,7 +790,7 @@ puts(tok);
 LOCAL void table_output_html ( void )
 {
 	int		y, x;
-	char	f[512], alignOn[64];
+	char	f[LINELEN], alignOn[64]; /* r6.3.18[vj]: f is now LINELEN chars long instead of 512 */
 	BOOLEAN inside_center, inside_right, inside_left;
 
 	inside_center= (iEnvLevel>0 && iEnvType[iEnvLevel]==ENV_CENT);
@@ -802,8 +807,8 @@ LOCAL void table_output_html ( void )
 	}
 
 	strcpy(alignOn, "left");
-	if (inside_center)	strcpy(alignOn, "center");
-	if (inside_right)	strcpy(alignOn, "right");
+	if (inside_center)	um_strcpy(alignOn, "center", 64, "table_output_html[1]");
+	if (inside_right)	um_strcpy(alignOn, "right", 64, "table_output_html[2]");
 
 	voutf("<div align=\"%s\">", alignOn);
 
@@ -838,7 +843,7 @@ LOCAL void table_output_html ( void )
 			    found = strstr(tab_cell[y][x], "!?");
 
 			if(found != NULL)
-			{	strncpy(token, tab_cell[y][x], strcspn(tab_cell[y][x], "!"));
+			{	um_strncpy(token, tab_cell[y][x], strcspn(tab_cell[y][x], "!"), MAX_TOKEN_LEN+1, "table_output_html[3]"); /* <???> Pufferberlauf mglich? Wie gro kann hier token wirklich sein? */
 
 				test_for_addition(token);
 
@@ -858,7 +863,7 @@ LOCAL void table_output_html ( void )
 			}
 */			out(sHtmlPropfontStart);
 			if ( tab_cell[y][x]!=NULL )
-			{	strcpy(f, tab_cell[y][x]);
+			{	um_strcpy(f, tab_cell[y][x], LINELEN, "table_output_html[4]");
 				auto_quote_chars(f, FALSE);
 				replace_defines(f);
 				c_commands_inside(f, FALSE);
@@ -1569,7 +1574,7 @@ GLOBAL void set_table_alignment ( void )
 {
 	char s[256];
 
-	tokcpy2(s);
+	tokcpy2(s, 256);
 
 	if (strstr(s, "center")!=NULL)
 	{	table_alignment= ALIGN_CENT;
