@@ -44,6 +44,7 @@ const char *id_tp_c= "@(#) tp.c        11.02.1999";
 
 #include "export.h"
 #include "tp.h"
+#include "udomem.h"
 
 
 /*	############################################################
@@ -75,6 +76,9 @@ LOCAL void free_titdat ( char **var );
 	--------------------------------------------------------------	*/
 GLOBAL BOOLEAN set_mainlayout ( void )
 {
+	/* Fixed Bug #0000040 in r6.3pl16 [NHz] */
+	init_docinfo_data("A4PORTRAIT", &(laydat.paper), FALSE);
+
 	init_docinfo_data("Times New Roman", &(laydat.propfontname), FALSE);
 	laydat.propfontsize = 11;
 	init_docinfo_data("Courier New", &(laydat.monofontname), FALSE);
@@ -116,7 +120,7 @@ GLOBAL BOOLEAN set_doclayout ( void )
 	char *page, page2[2];
 	struct size_brackets contlen;
 
-	tokcpy2(s);
+	tokcpy2(s, 512);
 	
 	contlen= get_two_brackets_ptr(s, &cont_format, &cont_content, &data);
 	
@@ -284,7 +288,7 @@ LOCAL BOOLEAN init_docinfo_data ( char *data, char **var, int allow_empty )
 	*/
 	char *buffer;
 	
-	buffer= (char *) malloc (strlen(data)*sizeof(char)+1);
+	buffer= (char *) um_malloc (strlen(data)*sizeof(char)+1);
 
 	if (buffer) /* Check if the buffer could be allocated */
 	{
@@ -336,8 +340,10 @@ GLOBAL BOOLEAN set_docinfo ( void )
 	char sDriv[512], sPath[512], sFile[512], sSuff[512];
 	size_t contlen;
 
-	tokcpy2(s);
-	
+	tokcpy2(s, 512);
+	/* New: Fixed bug #0000040 in r6.3pl16 [NHz] */
+	node2postscript(s, KPS_PS2DOCINFO);
+
 	contlen= get_brackets_ptr(s, &cont, &data);
 	
 	if (contlen==0 || cont==NULL || data==NULL)
@@ -350,6 +356,9 @@ GLOBAL BOOLEAN set_docinfo ( void )
 	inhalt[contlen]= EOS;
 	del_whitespaces(inhalt);
 
+	/* New: Fixed Bug #0000040 in r6.3pl16 [NHz] */
+	node2postscript(data, KPS_DOCINFO2PS);
+
 	if (strcmp(inhalt, "authorimage")==0)
 	{	del_whitespaces(data);
 		if (data[0]==EOS)
@@ -357,7 +366,7 @@ GLOBAL BOOLEAN set_docinfo ( void )
 		}
 		else
 		{	path_adjust_separator(data);
-			buffer= (char *) malloc ( strlen(data)*sizeof(char)+1 );
+			buffer= (char *) um_malloc ( strlen(data)*sizeof(char)+1 );
 			if (buffer)
 			{	strcpy(buffer, data);
 				titdat.authorimage= buffer;
@@ -385,7 +394,7 @@ GLOBAL BOOLEAN set_docinfo ( void )
 			fsplit(data, sDriv, sPath, sFile, sSuff);
 			sprintf(data, "%s%s%s", sPath, sFile, sDocImgSuffix);
 			path_adjust_separator(data);
-			buffer= (char *) malloc ( strlen(data)*sizeof(char)+1 );
+			buffer= (char *) um_malloc ( strlen(data)*sizeof(char)+1 );
 			if (buffer)
 			{	strcpy(buffer, data);
 				titdat.authoricon= buffer;
@@ -421,7 +430,7 @@ GLOBAL BOOLEAN set_docinfo ( void )
 			fsplit(data, sDriv, sPath, sFile, sSuff);
 			sprintf(data, "%s%s%s", sPath, sFile, sDocImgSuffix);
 			path_adjust_separator(data);
-			buffer= (char *) malloc ( strlen(data)*sizeof(char)+1 );
+			buffer= (char *) um_malloc ( strlen(data)*sizeof(char)+1 );
 			if (buffer)
 			{	strcpy(buffer, data);
 				titdat.authoricon_active= buffer;
@@ -454,7 +463,7 @@ GLOBAL BOOLEAN set_docinfo ( void )
 		}
 		else
 		{	path_adjust_separator(data);
-			buffer= (char *) malloc ( strlen(data)*sizeof(char)+1 );
+			buffer= (char *) um_malloc ( strlen(data)*sizeof(char)+1 );
 			if (buffer)
 			{	strcpy(buffer, data);
 				titdat.programimage= buffer;
@@ -557,7 +566,7 @@ GLOBAL BOOLEAN set_docinfo ( void )
 		{	error_empty_docinfo();
 		}
 		else
-		{	buffer= (char *) malloc ( strlen(data)*sizeof(char)+1 );
+		{	buffer= (char *) um_malloc ( strlen(data)*sizeof(char)+1 );
 			if (buffer)
 			{	strcpy(buffer, data);
 				titdat.webmasterurl= buffer;
@@ -1333,6 +1342,8 @@ GLOBAL void c_maketitle ( void )
 				outln("newline");
 			}
 			c_newpage();
+			/* New: Fixed bug #0000040 in r6.3pl16 [NHz] */
+			outln("newline");
 			break;
 
 	}
@@ -1453,7 +1464,7 @@ GLOBAL void init_module_tp_pass2 ( void )
 LOCAL void free_titdat ( char **var )
 {
 	if (*var!=NULL)
-	{	free(*var);
+	{	um_free(*var);
 		*var= NULL;
 	}
 }
